package Evo::Inference::InferenceParser;

sub new {
	my ($class) = @_;

	my $self = {
	};

	$class = ref($class) || $class;

	bless $self, $class;
}

sub parse {
	my ($self, $cond, @condargs) = @_;

	return $cond->solve(@condargs);	
}

1;
